@@ -4,18 +4,14 @@
 modname = 'comment'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 6, 3)
+numversion = (1, 10, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
-
 author = "Logilab"
 author_email = "contact@logilab.fr"
 web = 'http://www.cubicweb.org/project/%s' % distname
-
 description = "commenting system for the CubicWeb framework"
-short_desc = description # XXX cw < 3.8 bw compat
-
 classifiers = [
            'Environment :: Web Environment',
            'Framework :: CubicWeb',
@@ -23,12 +19,13 @@ classifiers = [
            'Programming Language :: JavaScript',
 ]
 
-__depends__ = {'cubicweb': '>= 3.6.0'}
+__depends__ = {'cubicweb': '>= 3.17.12'}
 
-# package ###
+
+# packaging ###
 
 from os import listdir as _listdir
-from os.path import join, isdir, exists
+from os.path import join, isdir
 from glob import glob
 
 THIS_CUBE_DIR = join('share', 'cubicweb', 'cubes', modname)
@@ -44,6 +41,8 @@ data_files = [
     [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
     ]
 # check for possible extended cube layout
-for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration'):
-    if isdir(dname):
-        data_files.append([join(THIS_CUBE_DIR, dname), listdir(dname)])
+for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration', 'wdoc'):
+    if isdir(dirname):
+        data_files.append([join(THIS_CUBE_DIR, dirname), listdir(dirname)])
+# Note: here, you'll need to add subdirectories if you want
+# them to be included in the debian package
